@@ -28,7 +28,7 @@ test="correlation"
 test="cluster"
 test="nested_piechart"
 test="radialtree"
-test="stacked"
+test="scatterplot"
 
 
 if test=="stackedlines":
@@ -229,8 +229,8 @@ elif test=="cluster":
     df=df.dropna(axis=0)
     features=["species","sex","bill_length_mm","bill_depth_mm","flipper_length_mm","body_mass_g"]
     df=df[features]
-    op.clusterplot(df,category=["species","sex"],method="kmeans",n_clusters="auto", markers=True,topn_cluster_num=3,reduce_dimension="tsne")
-    #clusterplot(df,category=["species","sex"],method="fuzzy",n_clusters="auto", piesize_scale=0.03,topn_cluster_num=3)
+    #op.clusterplot(df,category=["species","sex"],method="kmeans",n_clusters="auto", markers=True,topn_cluster_num=3,reduce_dimension="tsne")
+    op.clusterplot(df,category=["species","sex"],method="fuzzy",n_clusters=3, piesize_scale=0.03,sp_kw={"marginal_dist":True})#,topn_cluster_num=3)
     #clusterplot(df,category=["species","sex"],method="hdbscan",eps=0.35)
     #clusterplot(df,category=["species","sex"],method="hdbscan",n_clusters="auto")
     plt.show()
@@ -259,10 +259,16 @@ elif test=="scatterplot":
     #features=["species","sex","bill_length_mm","bill_depth_mm","flipper_length_mm","body_mass_g"]
     #df=df[features]
     print(df.shape)
-    op.scatterplot(df, x="bill_length_mm",y="bill_depth_mm",xunit="mm", yunit="mm", category=['species',"sex","island"],
-                   colors=["flipper_length_mm"],sizes="body_mass_g",show_labels={"val": "body_mass_g", "topn":5}
+    op.scatterplot(df, x="bill_length_mm",y="bill_depth_mm",xunit="mm", yunit="mm", 
+                   category=['species',"sex","island"],
+                   colors=["flipper_length_mm"],
+                   sizes="body_mass_g",
+                   show_labels={"val": "body_mass_g", "topn":5},
+                   marginal_dist=True,
+                   kmeans=True,
                                                 )
-    op.scatterplot(df, 
+    fig, ax=plt.subplots()
+    op.scatterplot(df, ax=ax,
                x="bill_length_mm",
                y="bill_depth_mm", 
                 sizes="flipper_length_mm")
